/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.client.alerters;

//---IMPORTS---
import uk.org.iscream.cms.server.client.*;
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * Provides a full Alert feed to the singleton instnace
 * of the WebFeeder.
 *
 * See the WebFeeder class for details.
 *
 * @author  $Author: tdb $
 * @version $Id: WebFeeder__Alerter.java,v 1.12 2003/02/05 16:43:45 tdb Exp $
 */
public class WebFeeder__Alerter extends AlerterSkeleton {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public static final String REVISION = "$Revision: 1.12 $";
    
    /**
     * A description of this alerter
     */    
    public static final String DESC = "Provides a feed to WebFeeder";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

//---PUBLIC METHODS---

    public void sendAlert(Alert alert) {
        try {
            _cp.getInstance().getProperty("WebFeeder", "WebFeeder.alertActive");
            WebFeeder.getInstance().receiveAlert(alert);
        } catch (PropertyNotFoundException e) {
            // we don't care, this means we shouldn't be active
        }
    }

    /**
     * Return the String representation of what the alerter does
     *
     * @return the description
     */
    public String getDescription() {
        return DESC;
    }

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.FormatName class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

    /**
     * Returns the "friendly" name of this class. This
     * is simply an accessor for _name, required due to
     * inheritance issues with extending AlerterSkeleton.
     *
     * @return the friendly name
     */
    protected String getFName() {
        return _name;
    }

//---ATTRIBUTES---

    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = "WebFeeder";

//---STATIC ATTRIBUTES---

}
