/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.clientinterface;

//---IMPORTS---
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * This class, a servant, listens for incoming data sent to it
 * using CORBA. This data is then queued in the PacketSorter.
 * It does no processing of the data, and is only a seperate
 * class to keep the CORBA stuff out of the PacketSorter.
 *
 * @author  $Author: tdb $
 * @version $Id: ClientInterfaceServant.java,v 1.14 2003/02/05 16:43:46 tdb Exp $
 */
class ClientInterfaceServant extends ClientInterfacePOA {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public final String REVISION = "$Revision: 1.14 $";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

    /**
     * Creates a new ClientInterfaceServant.
     *
     * @param packetSorter a reference to the PacketSorter object being used
     */
    public ClientInterfaceServant(PacketSorter packetSorter) {
        _queue = packetSorter.getQueue();
        _logger.write(toString(), Logger.SYSINIT, "created");
    }
    
//---PUBLIC METHODS---

    /**
     * Method to receive a string over CORBA.
     *
     * @param xml the XML string to be queued for processing.
     */
    public void receiveXML(String xml) {
        _queue.add(xml);
    }
    
    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.NameFormat class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = ClientInterfaceMain.NAME;

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger = ReferenceManager.getInstance().getLogger();
    
    /**
     * A reference to the Queue we'll add data to. This is
     * actually located in the PacketSorter.
     */
    private Queue _queue;
    
//---STATIC ATTRIBUTES---

}
