/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.dbinterface;

//---IMPORTS---
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.clientinterface.*;
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * Receives XML and adds it to a Queue for processing.
 *
 * @author  $Author: tdb $
 * @version $Id: DBServant.java,v 1.5 2003/02/05 16:43:47 tdb Exp $
 */
public class DBServant extends ClientInterfacePOA {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public final String REVISION = "$Revision: 1.5 $";

//---STATIC METHODS---

//---CONSTRUCTORS---

    public DBServant(Queue queue) throws ComponentStartException {
        _queue = queue;
        _logger.write(toString(), Logger.SYSINIT, "created");
    }

//---PUBLIC METHODS---

    /**
     * Implements the ClientInterface
     *
     * @param xml the xml data to be placed into the queue
     */
    public void receiveXML(String xml) {
        // Create a new XMLPacketWrapper
        XMLPacketWrapper xpw = null;
        try {
            xpw = new XMLPacketWrapper(xml);
        } catch(InvalidXMLException e) {
            _logger.write(toString(), Logger.ERROR, "Invalid XML: "+e);
            // leave this method
            return;
        }
        // Queue the data
        _queue.add(xpw);
    }
    
    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.NameFormat class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            this.getClass().getName(),
            REVISION);
    }
    
//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---
    
    /**
     * Queue to put XML in
     */
    private Queue _queue;
    
    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = DBInterface.NAME;

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger = ReferenceManager.getInstance().getLogger();

//---STATIC ATTRIBUTES---

}   
