/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.filter.plugins;

//---IMPORTS---
import uk.org.iscream.cms.server.filter.PluginFilter;
import uk.org.iscream.cms.server.filter.*;
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * This plugin is designed to check the source of incoming
 * packets, and ensure the source machine is permitted to
 * send packets through the system.
 *
 * @author  $Author: tdb $
 * @version $Id: SourceChecker__Plugin.java,v 1.6 2003/02/24 20:18:49 tdb Exp $
 */
public class SourceChecker__Plugin implements PluginFilter {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public final String REVISION = "$Revision: 1.6 $";
    
    public final String DESC = "Checks the machine_name attribute in the packet attributes. This must machine must be permitted by the ACL to allow the packet through.";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

    public SourceChecker__Plugin() {
        // setup an empty ACL defaulting to ALLOW
        _acl = new ACL(ACL.ALLOW);
    }

//---PUBLIC METHODS---

    // apply the filter and return true if successful.
    public boolean runFilter(XMLPacket packet){
        String newStringACL;
        // get hold of the ACL in the configuration
        try {
            newStringACL = ConfigurationProxy.getInstance().getProperty("Filter." + FilterMain.NAME, "Filter.SourceCheckerPluginACL");
        }
        catch(PropertyNotFoundException e) {
            // if we can't find it, we'll just use a null ACL
            newStringACL = "";
            _logger.write(toString(), Logger.WARNING, "No ACL found for SourceChecker__Plugin, using empty ACL instead : " + e);
        }
        // check to see if the ACL has changed
        if(!newStringACL.equals(_stringACL)) {
            _logger.write(toString(), Logger.SYSMSG, "Reloading Access Control List");
            // clear the ACL
            _acl.clear();
            // set the default to something sane
            _acl.setDefaultMode(ACL.ALLOW);
            // add the new ACL (this may change the default)
            _acl.add(newStringACL);
            _stringACL = newStringACL;
        }
        
        // only want to check data packets
        // any others will probably get filtered out further up the filter chain
        if(packet.getParam("packet.attributes.type").equals("data")) {
            // check the machine name against the ACL
            // we could check the IP too... but it's a lot of work for _every_ packet... maybe...
            return _acl.check(packet.getParam("packet.attributes.machine_name"));
        }
        
        // a good catchall, I guess
        // it's not a data packet, in which case it should go through
        return true;
    }

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.NameFormat class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

    /**
     * return the String representation of what the filter does
     */
    public String getDescription(){
        return DESC;
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = FilterMain.NAME;

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger = ReferenceManager.getInstance().getLogger();

    /**
     * This holds the ACL for the plugin.
     */
    private ACL _acl;
    
    /**
     * The current String representation of our ACL.
     */
    private String _stringACL = "";

//---STATIC ATTRIBUTES---

}
